## ----, echo=FALSE, warning=FALSE-----------------------------------------
myecho <- TRUE
myeval <- TRUE
library(knitr)
library(DSsim)

## ----packages, echo=myecho, eval=FALSE-----------------------------------
## needed.packages <- c("DSsim", "mrds", "shapefiles", "splancs")
## myrepo <- "http://cran.rstudio.com"
## install.packages(needed.packages, repos=myrepo)

## ----setdir, echo=myecho, eval=myeval------------------------------------

## ----shapes, echo=myecho, eval=myeval------------------------------------
library(shapefiles)
region.shapefile <- read.shapefile("DSsim_study/Region")

## ----makereg, echo=myecho, eval=myeval-----------------------------------
region <- make.region(region.name = "Survey Region", units = "m", shapefile = region.shapefile)

## ----plotreg, echo=myecho, eval=myeval-----------------------------------
plot(region, plot.units = "km")

## ----othersurf, echo=myecho, eval=FALSE----------------------------------
## density <- make.density(region = region, x.space = 1000, y.space = 1000, constant = 0.4e-7)
## 
## density <- add.hotspot(density, centre = c(-2500, 2224000), sigma = 10000, amplitude = 0.1e-7)
## density <- add.hotspot(density, centre = c(0, 2184000), sigma = 18000, amplitude = -0.5e-8)

## ----loadsurf, echo=myecho, eval=myeval----------------------------------
# premade.surface <- paste(my.directory, "density.surface.robj", sep="/")
load("DSsim_study/density.surface.robj")
head(density.surface[[1]])

## ----popden, echo=myecho, eval=myeval------------------------------------
pop.density <- make.density(region = region, density.surface = density.surface, x.space = 1000, y.space = 1000) 

## ----viewden, echo=myecho, eval=myeval-----------------------------------
plot(pop.density, plot.units = "km")
plot(region, add = TRUE)

## ----abund, echo=myecho, eval=myeval-------------------------------------
pop.description <- make.population.description(region.obj = region, density.obj = pop.density, N = 1500, fixed.N = TRUE)

## ----truedetect, echo=myecho, eval=myeval--------------------------------
detect <- make.detectability(key.function = "hn", scale.param = 500, truncation = 1000)

## ----subjpath, echo=myecho, eval=myeval----------------------------------
new.directory <- paste(getwd(), "DSsim_study/Survey_Transects/Subjective_Design", sep="/")
subjective.design <- make.design(transect.type = "Line", design.details = c("user specified"), region = region, plus.sampling = FALSE, path = new.directory)
subjective.design@filenames

## ----candidate.detfns, echo=myecho, eval=myeval--------------------------
ddf.analyses <- make.ddf.analysis.list(
        dsmodel = list(~cds(key = "hn", formula = ~1), #half-normal model
        ~cds(key = "hr", formula = ~1)),               #hazard-rate model
        method = "ds", criteria = "AIC")

## ----simobj, echo=myecho, eval=myeval------------------------------------
my.simulation.subjective <- make.simulation(reps = 10, single.transect.set = TRUE, region.obj = region, design.obj = subjective.design, population.description.obj = pop.description, detectability.obj = detect, ddf.analyses.list = ddf.analyses)

## ----simproperties, eval=myeval, echo=myecho-----------------------------
#set the display window up for 4 plots
par(mfrow = c(2,2))

#generate and plot and example population
pop <- generate.population(my.simulation.subjective)
plot(region)
plot(pop)

#generate (or rather load from file) the transects
transects <- generate.transects(my.simulation.subjective)
plot(region)
plot(transects, col = 4, lwd = 2)

#simulate the survey process of detection
eg.survey <- create.survey.results(my.simulation.subjective)
plot(eg.survey)

#have a look at the distance data from the simulated survey
dist.data <- get.distance.data(eg.survey)
head(dist.data)
hist(dist.data$distance, xlab = "Distance (m)", main = "Distance Data")
par(mfrow=c(1,1))

## ----runsim, echo=myecho, eval=myeval------------------------------------
my.simulation.subjective.run  <- run(my.simulation.subjective)
summary(my.simulation.subjective.run)

